@@ -71,19 +71,18 @@ class DAWG:
         lChar = ['']; dChar = {}; nChar = 1; dCharOccur = {}
         lAff  = [];   dAff  = {}; nAff  = 0; dAffOccur = {}
         lTag  = [];   dTag  = {}; nTag  = 0; dTagOccur = {}
-        nErr = 0
 
         self.a2grams = set()
 
         try:
             zFilter = re.compile(sSelectFilterRegex)  if sSelectFilterRegex  else None
-        except:
-            print(" # Error. Wrong filter regex. Filter ignored.")
+        except re.error:
+            print("# Error. Wrong filter regex. Filter ignored: ", zFilter)
             traceback.print_exc()
             zFilter = None
 
         # read lexicon
-        if type(src) is str:
+        if isinstance(src, str):
             iterable = readFile(src)
         else:
             iterable = src
@@ -127,7 +126,7 @@ class DAWG:
                         + [ (dAff[aff]+nChar, dAffOccur[aff]) for aff in dAff ] \
                         + [ (dTag[tag]+nChar+nAff, dTagOccur[tag]) for tag in dTag ] )
 
-        self.sFileName = src  if type(src) is str  else "[None]"
+        self.sFileName = src  if isinstance(src, str)  else "[None]"
         self.sLangCode = sLangCode
         self.sLangName = sLangName
         self.sDicName = sDicName
@@ -160,6 +159,12 @@ class DAWG:
         else:
             self.funcStemming = st.noStemming
 
+        # calculated later
+        self.nBytesNodeAddress = 1
+        self.nBytesArc = 0
+        self.nBytesOffset = 0
+        self.nMaxOffset = 0
+
         # build
         lWord.sort()
         oProgBar = ProgressBar(0, len(lWord))
@@ -193,7 +198,7 @@ class DAWG:
         self._minimize(nCommonPrefix)
 
         # add the suffix, starting from the correct node mid-way through the graph
-        if len(self.lUncheckedNodes) == 0:
+        if not self.lUncheckedNodes:
             oNode = self.oRoot
         else:
             oNode = self.lUncheckedNodes[-1][2]
@@ -334,7 +339,7 @@ class DAWG:
         if sPattern:
             try:
                 zPattern = re.compile(sPattern)
-            except:
+            except re.error:
                 print("# Error in regex pattern")
                 traceback.print_exc()
         yield from self._select(zPattern, self.oRoot, "")
@@ -669,7 +674,7 @@ class DawgNode:
         nArc = len(self.arcs)
         nFinalNodeMask = 1 << ((nBytesArc*8)-1)
         nFinalArcMask = 1 << ((nBytesArc*8)-2)
-        if len(self.arcs) == 0:
+        if not nArc:
             val = nFinalNodeMask | nFinalArcMask
             by = val.to_bytes(nBytesArc, byteorder='big')
             by += (0).to_bytes(nBytesNodeAddress, byteorder='big')
@@ -691,7 +696,7 @@ class DawgNode:
         nFinalNodeMask = 1 << ((nBytesArc*8)-1)
         nFinalArcMask = 1 << ((nBytesArc*8)-2)
         s = "i{:_>10} -- #{:_>10}\n".format(self.i, self.addr)
-        if len(self.arcs) == 0:
+        if not nArc:
             s += "  {:<20}  {:0>16}  i{:_>10}   #{:_>10}\n".format("", bin(nFinalNodeMask | nFinalArcMask)[2:], "0", "0")
             return s
         for i, arc in enumerate(self.arcs, 1):
@@ -731,7 +736,7 @@ class DawgNode:
         nFinalNodeMask = 1 << ((nBytesArc*8)-1)
         nFinalArcMask = 1 << ((nBytesArc*8)-2)
         nNextNodeMask = 1 << ((nBytesArc*8)-3)
-        if len(self.arcs) == 0:
+        if not nArc:
             val = nFinalNodeMask | nFinalArcMask
             by = val.to_bytes(nBytesArc, byteorder='big')
             by += (0).to_bytes(nBytesNodeAddress, byteorder='big')
@@ -758,7 +763,7 @@ class DawgNode:
         nFinalArcMask = 1 << ((nBytesArc*8)-2)
         nNextNodeMask = 1 << ((nBytesArc*8)-3)
         s = "i{:_>10} -- #{:_>10}\n".format(self.i, self.addr)
-        if nArc == 0:
+        if not nArc:
             s += "  {:<20}  {:0>16}  i{:_>10}   #{:_>10}\n".format("", bin(nFinalNodeMask | nFinalArcMask)[2:], "0", "0")
             return s
         for i, arc in enumerate(self.arcs, 1):
@@ -808,7 +813,7 @@ class DawgNode:
         nFinalArcMask = 1 << ((nBytesArc*8)-2)
         nNextNodeMask = 1 << ((nBytesArc*8)-3)
         nMaxOffset = (2 ** (nBytesOffset * 8)) - 1
-        if nArc == 0:
+        if not nArc:
             val = nFinalNodeMask | nFinalArcMask
             by = val.to_bytes(nBytesArc, byteorder='big')
             by += (0).to_bytes(nBytesNodeAddress, byteorder='big')
@@ -837,7 +842,7 @@ class DawgNode:
         nNextNodeMask = 1 << ((nBytesArc*8)-3)
         nMaxOffset = (2 ** (nBytesOffset * 8)) - 1
         s = "i{:_>10} -- #{:_>10}  ({})\n".format(self.i, self.addr, self.size)
-        if nArc == 0:
+        if not nArc:
             s += "  {:<20}  {:0>16}  i{:_>10}   #{:_>10}\n".format("", bin(nFinalNodeMask | nFinalArcMask)[2:], "0", "0")
             return s
         for i, arc in enumerate(self.arcs, 1):
